@@ -6,6 +6,7 @@ import os  # Executing commands.
 import json  # For opening JSONs.
 import shutil  # For zipping folders.
 from time import sleep  # For waiting on action
+import tempfile
 
 app = typer.Typer(help="Package manager for text adventure games.", name="mait")
 
@@ -47,7 +48,7 @@ def play(game: str):
     temp_dir = tempfile.TemporaryDirectory()
 
     def execute(game):
-        with open(f'{temp_dir}/{game}/mait.json', 'r') as r:
+        with open(f'{temp_dir.name}/{game}/mait.json', 'r') as r:
             data = json.load(r)
 
         try:
@@ -73,6 +74,7 @@ def play(game: str):
 Name: {name}
 Short: {short}
 Creator: {creator}
+
 Description:
 {long}
         """)
@@ -89,7 +91,7 @@ Description:
             os.system('cls')
         else:
             os.system('clear')
-        os.chdir(f'{temp_dir}/{game}')
+        os.chdir(f'{temp_dir.name}/{game}')
         os.system(data['exec'])
 
     with socket.socket(socket.AF_INET, socket.SOCK_DGRAM) as s:
@@ -103,7 +105,7 @@ Description:
             size = len(size) * 2
             bar()
             print(size)
-            f = open(f'{temp_dir}/{game}.zip', 'wb')
+            f = open(f'{temp_dir.name}/{game}.zip', 'wb')
 
             l = s.recvfrom(size)
             f.write(l[0])
@@ -111,7 +113,7 @@ Description:
             bar()
             # https://stackoverflow.com/questions/3083235/unzipping-file-results-in-badzipfile-file-is-not-a-zip-file
             # God bless their souls.
-            f = open(f'{temp_dir}/{game}.zip', 'r+b')
+            f = open(f'{temp_dir.name}/{game}.zip', 'r+b')
             data = f.read()
             pos = data.find(b'\x50\x4b\x05\x06')  # End of central directory signature
             if (pos > 0):
@@ -124,13 +126,13 @@ Description:
             bar()
 
         try:
-            os.mkdir(f'{temp_dir}/{game}')
+            os.mkdir(f'{temp_dir.name}/{game}')
         except FileExistsError:
             s.close()
             execute(game)
 
-        shutil.unpack_archive(f'.{temp_dir}/{game}.zip', f'{temp_dir}/{game}')
-        os.remove(f'{temp_dir}/{game}.zip')
+        shutil.unpack_archive(f'{temp_dir.name}/{game}.zip', f'{temp_dir.name}/{game}')
+        os.remove(f'{temp_dir.name}/{game}.zip')
         bar()
 
         s.close()
